enough.community documentation
==============================

The `Enough infrastructure
<http://lab.enough.community/main/infrastructure>`_ is a set of
services (forum, chat, shared storage, monitoring, backups, intrusion detection,
etc.). It is designed
to be `self-hosted <https://en.wikipedia.org/wiki/Self-hosting_(web_services)>`__
but there also exist a `publicly available instance <https://enough.community>`__.

It is maintained by :doc:`individuals <community/team>` organized
`horizontally
<https://enough.community/blog/2020/01/20/manifesto/>`__. Anyone is
welcome to contribute: learn more in the :doc:`contribution guide
<community/contribute>`.

.. toctree::
  :caption: Infrastructure guide
  :name: Infrastructure guide
  :maxdepth: 2

  introduction
  user-guide
  services/index
  community/index
  release-notes
